Main functions
==============

.. autosummary::

    nngt.generate
    nngt.get_config
    nngt.load_from_file
    nngt.num_mpi_processes
    nngt.on_master_process
    nngt.save_to_file
    nngt.seed
    nngt.set_config
    nngt.use_backend


Details
-------

.. currentmodule:: nngt

.. autofunction:: generate

.. autofunction:: get_config

.. autofunction:: load_from_file

.. autofunction:: num_mpi_processes

.. autofunction:: on_master_process

.. autofunction:: save_to_file

.. autofunction:: seed

.. autofunction:: set_config

.. autofunction:: use_backend
